@@ -19,13 +19,27 @@ use gst::glib;
 
 mod sink;
 mod utils;
+pub use sink::frame::Orientation;
+pub use sink::paintable::Paintable;
+// The widget needs to be public so it can be used by the example and element debug window but
+// we don't want it be part of the official API for now.
+#[doc(hidden)]
+pub use sink::render_widget::RenderWidget;
 pub use sink::PaintableSink;
 
 fn plugin_init(plugin: &gst::Plugin) -> Result<(), glib::BoolError> {
+    #[cfg(feature = "doc")]
+    {
+        use gst::prelude::*;
+
+        sink::paintable::Paintable::static_type().mark_as_plugin_api(gst::PluginAPIFlags::empty());
+        sink::frame::Orientation::static_type().mark_as_plugin_api(gst::PluginAPIFlags::empty());
+    }
+
     #[cfg(not(feature = "gtk_v4_10"))]
     {
         if gtk::micro_version() >= 13 {
-            gst::warning!(sink::imp::CAT, obj: plugin, "GTK 4.13 or newer detected but plugin not compiled with support for this version. Rendering of video frames with alpha will likely be wrong");
+            gst::warning!(sink::imp::CAT, obj = plugin, "GTK 4.13 or newer detected but plugin not compiled with support for this version. Rendering of video frames with alpha will likely be wrong");
         }
     }
 
