@@ -88,8 +88,6 @@ enum MappedFrame {
         fds: [i32; 4],
         offsets: [usize; 4],
         strides: [usize; 4],
-        width: u32,
-        height: u32,
         orientation: Orientation,
     },
 }
@@ -272,6 +270,34 @@ fn video_format_to_memory_format(f: gst_video::VideoFormat) -> gdk::MemoryFormat
         gst_video::VideoFormat::Y42b => gdk::MemoryFormat::G8B8R8422,
         #[cfg(feature = "gtk_v4_20")]
         gst_video::VideoFormat::Y444 => gdk::MemoryFormat::G8B8R8444,
+        #[cfg(feature = "gtk_v4_20")]
+        gst_video::VideoFormat::I42010le => gdk::MemoryFormat::X6g10X6b10X6r10420,
+        #[cfg(feature = "gtk_v4_20")]
+        gst_video::VideoFormat::I42010be => gdk::MemoryFormat::X6g10X6b10X6r10420,
+        #[cfg(feature = "gtk_v4_20")]
+        gst_video::VideoFormat::I42210le => gdk::MemoryFormat::X6g10X6b10X6r10422,
+        #[cfg(feature = "gtk_v4_20")]
+        gst_video::VideoFormat::I42210be => gdk::MemoryFormat::X6g10X6b10X6r10422,
+        #[cfg(feature = "gtk_v4_20")]
+        gst_video::VideoFormat::Y44410le => gdk::MemoryFormat::X6g10X6b10X6r10444,
+        #[cfg(feature = "gtk_v4_20")]
+        gst_video::VideoFormat::Y44410be => gdk::MemoryFormat::X6g10X6b10X6r10444,
+        #[cfg(feature = "gtk_v4_20")]
+        gst_video::VideoFormat::I42012le => gdk::MemoryFormat::X4g12X4b12X4r12420,
+        #[cfg(feature = "gtk_v4_20")]
+        gst_video::VideoFormat::I42012be => gdk::MemoryFormat::X4g12X4b12X4r12420,
+        #[cfg(feature = "gtk_v4_20")]
+        gst_video::VideoFormat::I42212le => gdk::MemoryFormat::X4g12X4b12X4r12422,
+        #[cfg(feature = "gtk_v4_20")]
+        gst_video::VideoFormat::I42212be => gdk::MemoryFormat::X4g12X4b12X4r12422,
+        #[cfg(feature = "gtk_v4_20")]
+        gst_video::VideoFormat::Y44412le => gdk::MemoryFormat::X4g12X4b12X4r12444,
+        #[cfg(feature = "gtk_v4_20")]
+        gst_video::VideoFormat::Y44412be => gdk::MemoryFormat::X4g12X4b12X4r12444,
+        #[cfg(feature = "gtk_v4_20")]
+        gst_video::VideoFormat::Y44416le => gdk::MemoryFormat::G16B16R16444,
+        #[cfg(feature = "gtk_v4_20")]
+        gst_video::VideoFormat::Y44416be => gdk::MemoryFormat::G16B16R16444,
         #[cfg(feature = "gtk_v4_14")]
         gst_video::VideoFormat::Bgrx => gdk::MemoryFormat::B8g8r8x8,
         #[cfg(feature = "gtk_v4_14")]
@@ -343,6 +369,14 @@ fn videoinfo_to_color_state(info: &gst_video::VideoInfo) -> Option<gdk::ColorSta
     }
 }
 
+fn cropped_size_from_info(info: &gst_video::VideoInfo) -> (u32, u32) {
+    let w_sub = 1 << info.format_info().w_sub()[(info.n_components() as usize) - 1];
+    let h_sub = 1 << info.format_info().h_sub()[(info.n_components() as usize) - 1];
+    let cropped_width = info.width() - (info.width() % w_sub);
+    let cropped_height = info.height() - (info.width() % h_sub);
+    (cropped_width, cropped_height)
+}
+
 fn video_frame_to_memory_texture(
     frame: gst_video::VideoFrame<gst_video::video_frame::Readable>,
     cached_textures: &mut HashMap<TextureCacheId, gdk::Texture>,
@@ -359,8 +393,7 @@ fn video_frame_to_memory_texture(
     }
 
     let format = video_format_to_memory_format(frame.format());
-    let width = frame.width();
-    let height = frame.height();
+    let (width, height) = cropped_size_from_info(frame.info());
 
     let texture = {
         #[cfg(feature = "gtk_v4_20")]
@@ -422,8 +455,7 @@ fn video_frame_to_gl_texture(
         return (texture.clone(), pixel_aspect_ratio);
     }
 
-    let width = frame.width();
-    let height = frame.height();
+    let (width, height) = cropped_size_from_info(frame.info());
 
     let sync_meta = frame.buffer().meta::<gst_gl::GLSyncMeta>().unwrap();
 
@@ -542,8 +574,6 @@ fn video_frame_to_dmabuf_texture(
     fds: &[i32; 4],
     offsets: &[usize; 4],
     strides: &[usize; 4],
-    width: u32,
-    height: u32,
 ) -> Result<(gdk::Texture, f64), glib::Error> {
     let pixel_aspect_ratio = (info.par().numer() as f64) / (info.par().denom() as f64);
 
@@ -552,6 +582,7 @@ fn video_frame_to_dmabuf_texture(
         return Ok((texture.clone(), pixel_aspect_ratio));
     }
 
+    let (width, height) = cropped_size_from_info(&info.to_video_info().ok().unwrap());
     let mut builder = gdk::DmabufTextureBuilder::new()
         .set_display(&gdk::Display::default().unwrap())
         .set_fourcc(info.fourcc())
@@ -639,8 +670,6 @@ impl Frame {
                 fds,
                 offsets,
                 strides,
-                width,
-                height,
                 ..
             } => video_frame_to_dmabuf_texture(
                 buffer,
@@ -651,8 +680,6 @@ impl Frame {
                 &fds,
                 &offsets,
                 &strides,
-                width,
-                height,
             )?,
         };
 
@@ -713,8 +740,20 @@ impl Frame {
                 .peek_memory(0)
                 .is_memory_type::<gst_allocators::DmaBufMemory>()
         {
+            let drm_info;
+            let drm_info_ref = match info.dma_drm() {
+                Some(drm) => Some(drm),
+                None => match gst_video::VideoInfoDmaDrm::from_video_info(info, 0) {
+                    Ok(i) => {
+                        drm_info = Some(i);
+                        drm_info.as_ref()
+                    }
+                    Err(_) => None,
+                },
+            };
+
             if let Some((vmeta, info)) =
-                Option::zip(buffer.meta::<gst_video::VideoMeta>(), info.dma_drm())
+                Option::zip(buffer.meta::<gst_video::VideoMeta>(), drm_info_ref)
             {
                 let mut fds = [-1i32; 4];
                 let mut offsets = [0; 4];
@@ -752,11 +791,16 @@ impl Frame {
                         fds,
                         offsets,
                         strides,
-                        width: vmeta.width(),
-                        height: vmeta.height(),
                         orientation,
                     });
                 }
+                if frame.is_some() {
+                    gst::debug!(
+                        CAT,
+                        imp = dbg_obj,
+                        "Created frame using DmabufTextureBuilder"
+                    );
+                }
             }
         }
 
@@ -805,6 +849,9 @@ impl Frame {
                     wrapped_context: wrapped_context.unwrap().clone(),
                     orientation,
                 });
+                if frame.is_some() {
+                    gst::debug!(CAT, imp = dbg_obj, "Created frame using GLTextureBuilder");
+                }
             }
         }
 
@@ -843,11 +890,17 @@ impl Frame {
                         }
                     };
 
-                    MappedFrame::SysMem {
+                    let frame = MappedFrame::SysMem {
                         frame: gst_video::VideoFrame::from_buffer_readable(readable_frame, info)
                             .map_err(|_| gst::FlowError::Error)?,
                         orientation,
-                    }
+                    };
+                    gst::debug!(
+                        CAT,
+                        imp = dbg_obj,
+                        "Created frame using MemoryTextureBuilder"
+                    );
+                    frame
                 }
             },
             overlays: vec![],
